@@ -1,4 +1,5 @@
 from typing import Optional, Tuple, Union, Dict
+import math
 from enum import Enum
 import numpy as np
 from scipy.spatial.transform import Rotation
@@ -106,6 +107,16 @@ class Vector(Robotics):
     def __invert__(self):
         return self.__class__(*self._values.__invert__())
 
+    def __eq__(self, other: 'Vector'):
+        if not isinstance(other, Vector):
+            return False
+
+        for equal in np.isclose(self._values, other._values):
+            if not equal:
+                return False
+
+        return True
+
     @property
     def array(self) -> np.ndarray:
         return self._values
@@ -561,6 +572,12 @@ class Frame(Robotics):
 
         raise TypeError(f"Can't multiply frame by value of type '{other.__class__.__name__}'")
 
+    def __eq__(self, other: 'Frame'):
+        if not isinstance(other, Frame):
+            return False
+
+        return other._position == self._position and other._orientation == self._orientation
+
     @property
     def matrix(self) -> np.ndarray:
         frame_matrix = self._orientation.matrix_4x4
